.. _dir_example-name:

!!!!!!!!!!!
dir_example
!!!!!!!!!!!

.. meta::
  :keywords: dir_example,dir,command,example,factorial,square,tangent,xrst_literal,this,file

.. index:: dir_example, dir

.. _dir_example-title:

Dir Command Example
###################
This example is similar to the :ref:`literal_example-name` .

.. contents::
  :local:

.. index:: factorial

.. _dir_example@factorial:

factorial
*********
.. literalinclude:: ../../example/dir.cpp
   :start-after: // BEGIN_FACTORIAL
   :end-before:  // END_FACTORIAL

.. index:: square

.. _dir_example@square:

square
******
.. include:: ../../example/dir.cpp
   :start-after: // BEGIN_SQUARE
   :end-before:  // END_SQUARE

.. index:: tangent

.. _dir_example@tangent:

tangent
*******
.. include:: ../../example/dir.cpp
   :start-after: // BEGIN_TANGENT
   :end-before:  // END_TANGENT
   :literal:

.. index:: xrst_literal

.. _dir_example@xrst_literal:

xrst_literal
************
The file below demonstrates the use of ``xrst_dir`` .

.. _dir_example@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/dir.cpp
  :language: cpp
